globalVariables(unique(c(
  # c_index_2:
  "a1",
  "a2b1",
  "b2",
  "judge",
  # calculate_distance_NAa : helper:
  "_id",
  # calculate_numeric_scores:
  "_id",
  # create_boostrap_sample:
  "_id",
  # create_terminal_node_GL : <anonymous>:
  "_id",
  # forest:
  "id",
  # mse : mu1fun:
  "event",
  "event_count_pred",
  "t.stop",
  # mse_2:
  "event",
  "id",
  "event_count_pred",
  "t.stop",
  # predict_node_terminal:
  "_t.stop",
  "event_count",
  # preprocess_data_GL:
  ".env",
  # train_tree_and_calculate_metrics:
  "_original_id",
  "_t.start",
  "_t.stop",
  "event",
  "resFun",
  "trained_forest"
)))
